@@ -245,8 +245,10 @@ class IODict(BaseDict):
         """
         # if first argument is data-string, url or filepath try to decode it.
         # use 'format' kwarg to specify the decoder to use, default 'json'.
-        if format and format.lower():
-            d = IODict._decode_init(format, *args, **kwargs)
+        if format:
+            if  format.lower() in ["yml", "yaml"]:
+                self.yaml_initializer()
+            d = IODict._decode_init(*args, format=format, **kwargs)
             super().__init__(d, **kwargs)
             return
         super().__init__(*args, **kwargs)
@@ -256,23 +258,28 @@ class IODict(BaseDict):
         pass
 
     @staticmethod
-    def _decode_init(s, **kwargs):
+    def _decode_init(s,
+            format: Optional[str]=None,
+            **kwargs: Any
+        ) ->dict:
         autodetected_format = io.autodetect_format(s)
         default_format = autodetected_format or "json"
-        format = kwargs.pop("format", default_format).lower()
+        # format = kwargs.pop("format", default_format).lower()
+        format = format or default_format
         if format in ["b64", "base64"]:
             kwargs.setdefault("subformat", "json")
-        elif format in ["yml", "yaml"]:
-            self.yaml_initializer()
         # decode data-string and initialize with dict data.
-        return IODict._decode(s, format, **kwargs)
+        return IODict._decode(s, format=format, **kwargs)
 
     @staticmethod
-    def _decode(s, format, **kwargs):
+    def _decode(s,
+            format: str,
+            **kwargs: Any
+        ) ->dict:
         try:
-            content = io.read_content(s)
+            content = io.read_contents(s)
             # decode content using the given format
-            data = io.decode(content, format, **kwargs)
+            data = io.decode(content, format=format, **kwargs)
             if _type.is_dict(data):
                 return data
             elif _type.is_list(data):
@@ -410,9 +417,9 @@ class IODict(BaseDict):
         """
         kwargs["subformat"] = subformat
         kwargs["encoding"] = encoding
-        return self._encode(self.dict(), "base64", **kwargs)
+        return self._encode(self.to_dict(), "base64", **kwargs)
 
-    def to_csv(self, key="values", columns=None, columns_row=True, **kwargs):
+    def to_csv(self, key=None, columns=None, columns_row=True, **kwargs):
         """
         Encode a list of dicts in the current dict instance in CSV format.
         Encoder specific options can be passed using kwargs:
@@ -422,7 +429,9 @@ class IODict(BaseDict):
         """
         kwargs["columns"] = columns
         kwargs["columns_row"] = columns_row
-        return self._encode(self.dict()[key], "csv", **kwargs)
+        d = self.to_dict()
+        key = key or list(d.keys())[0]
+        return self._encode(d[key], "csv", **kwargs)
 
     def to_ini(self, **kwargs):
         """
@@ -432,7 +441,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self.dict(), "ini", **kwargs)
+        return self._encode(self.to_dict(), "ini", **kwargs)
 
     def to_json(self, **kwargs):
         """
@@ -442,7 +451,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self.dict(), "json", **kwargs)
+        return self._encode(self.to_dict(), "json", **kwargs)
 
     def to_pickle(self, **kwargs):
         """
@@ -453,7 +462,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self.dict(), "pickle", **kwargs)
+        return self._encode(self.to_dict(), "pickle", **kwargs)
 
     def to_plist(self, **kwargs):
         """
@@ -463,7 +472,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self.dict(), "plist", **kwargs)
+        return self._encode(self.to_dict(), "plist", **kwargs)
 
     def to_query_string(self, **kwargs):
         """
@@ -471,7 +480,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self.dict(), "query_string", **kwargs)
+        return self._encode(self.to_dict(), "query_string", **kwargs)
 
     def to_toml(self, **kwargs):
         """
@@ -481,7 +490,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self.dict(), "toml", **kwargs)
+        return self._encode(self.to_dict(), "toml", **kwargs)
 
     def to_xml(self, **kwargs):
         """
@@ -491,7 +500,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self.dict(), "xml", **kwargs)
+        return self._encode(self.to_dict(), "xml", **kwargs)
 
     def to_yaml(self, **kwargs):
         """
@@ -501,7 +510,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self.dict(), "yaml", **kwargs)
+        return self._encode(self.to_dict(), "yaml", **kwargs)
 
 
 class aDict(IODict):
@@ -515,7 +524,13 @@ class aDict(IODict):
         object.__setattr__(__self, '__key', kwargs.pop('__key', None))
         object.__setattr__(__self, '__frozen', False)
         if format:
-            args = super()._decode_init(format, *args, **kwargs)
+            if format.lower() in ["yml", "yaml"]:
+                io.yaml_initializer(cls=aDict)
+            args = (super()._decode_init(*args, format=format, **kwargs),)
+        else:
+            if args and isinstance(args[0], str) and io.validate_file(args[0]):
+                format = io.autodetect_format(args[0])
+                args = (super()._decode_init(*args, format=format, **kwargs),)
 
         for arg in args:
             if not arg:
@@ -743,10 +758,20 @@ class uDict(IODict):
     def __init__(self,
             *args: Any,
             separator: str=Default_Keypath_Separator,
+            format: Optional[str]=None,
             **kwargs: Any
         ):
         if separator:
             self._keypath_separator = separator
+        if format:
+            format = str(format).lower()
+            if format in ["yml", "yaml"]:
+                io.yaml_initializer(cls=uDict)
+            args = (super()._decode_init(*args, format=format, **kwargs),)
+        else:
+            if args and isinstance(args[0], str) and io.validate_file(args[0]):
+                format = io.autodetect_format(args[0])
+                args = (super()._decode_init(*args, format=format, **kwargs),)
         self.update(dict(*args, **kwargs))
 
     def __is_keypath_or_keylist(self, x):
@@ -1522,7 +1547,9 @@ class iList(list):
         self._check_frozen(thrown_error=True)
         return super().remove(val)
 
-    def without(self, *items):
+    def without(self,
+            *items: Any,
+        ) ->list:
         """ Create new list without items and return iterable.  """
         return list(set(self).difference(*items))
 
